# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.4] - 2025-09-03

### Added
- Add more folders to the build

## [2.0.3] - 2025-09-03

### Changed
- Bump version to v2.0.3 by @github-actions[bot]

### Fixed
- Uv build

## [2.0.2] - 2025-09-03

### Changed
- Bump version to v2.0.2 by @github-actions[bot]

### Fixed
- Uv.lock
- Right reference to module for wheel

## [2.0.1] - 2025-09-03

### Added
- Add include_path for custom includes
- Add copier template

### Changed
- Bump version to v2.0.1 by @github-actions[bot]
- Merge pull request #1 from clearskies-py/copier by @tnijboer in [#1](https://github.com/clearskies-py/doc-builder/pull/1)
- Update for tooling by @cmancone
- WIP by @cmancone
- Initial commit by @cmancone

## New Contributors
* @github-actions[bot] made their first contribution
* @ made their first contribution
* @tnijboer made their first contribution in [#1](https://github.com/clearskies-py/doc-builder/pull/1)
* @cmancone made their first contribution
[2.0.4]: https://github.com/clearskies-py/doc-builder/compare/v2.0.3..v2.0.4
[2.0.3]: https://github.com/clearskies-py/doc-builder/compare/v2.0.2..v2.0.3
[2.0.2]: https://github.com/clearskies-py/doc-builder/compare/v2.0.1..v2.0.2

<!-- generated by git-cliff -->
